# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["VariantCheckCreateResponse"]


class VariantCheckCreateResponse(BaseModel):
    created_at: str = FieldInfo(alias="createdAt")

    message: str

    request_id: str = FieldInfo(alias="requestId")

    status: Literal["pending", "processing"]

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from henry_sdk import HenrySDK, AsyncHenrySDK
from tests.utils import assert_matches_type
from henry_sdk.types import (
    ProductSearchResponse,
    ProductRetrieveDetailsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestProducts:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_details(self, client: HenrySDK) -> None:
        product = client.products.retrieve_details(
            product_id="1234567890",
        )
        assert_matches_type(ProductRetrieveDetailsResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_details(self, client: HenrySDK) -> None:
        response = client.products.with_raw_response.retrieve_details(
            product_id="1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        product = response.parse()
        assert_matches_type(ProductRetrieveDetailsResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_details(self, client: HenrySDK) -> None:
        with client.products.with_streaming_response.retrieve_details(
            product_id="1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            product = response.parse()
            assert_matches_type(ProductRetrieveDetailsResponse, product, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_search(self, client: HenrySDK) -> None:
        product = client.products.search(
            query="Nike Air Max",
        )
        assert_matches_type(ProductSearchResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_search_with_all_params(self, client: HenrySDK) -> None:
        product = client.products.search(
            query="Nike Air Max",
            color="Red",
            gender="Men",
            greater_than_price=100,
            limit=20,
            lower_than_price=100,
            manufacturer="Nike",
            region="US",
            size="10",
        )
        assert_matches_type(ProductSearchResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_search(self, client: HenrySDK) -> None:
        response = client.products.with_raw_response.search(
            query="Nike Air Max",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        product = response.parse()
        assert_matches_type(ProductSearchResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_search(self, client: HenrySDK) -> None:
        with client.products.with_streaming_response.search(
            query="Nike Air Max",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            product = response.parse()
            assert_matches_type(ProductSearchResponse, product, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncProducts:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_details(self, async_client: AsyncHenrySDK) -> None:
        product = await async_client.products.retrieve_details(
            product_id="1234567890",
        )
        assert_matches_type(ProductRetrieveDetailsResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_details(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.products.with_raw_response.retrieve_details(
            product_id="1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        product = await response.parse()
        assert_matches_type(ProductRetrieveDetailsResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_details(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.products.with_streaming_response.retrieve_details(
            product_id="1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            product = await response.parse()
            assert_matches_type(ProductRetrieveDetailsResponse, product, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_search(self, async_client: AsyncHenrySDK) -> None:
        product = await async_client.products.search(
            query="Nike Air Max",
        )
        assert_matches_type(ProductSearchResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        product = await async_client.products.search(
            query="Nike Air Max",
            color="Red",
            gender="Men",
            greater_than_price=100,
            limit=20,
            lower_than_price=100,
            manufacturer="Nike",
            region="US",
            size="10",
        )
        assert_matches_type(ProductSearchResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_search(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.products.with_raw_response.search(
            query="Nike Air Max",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        product = await response.parse()
        assert_matches_type(ProductSearchResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.products.with_streaming_response.search(
            query="Nike Air Max",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            product = await response.parse()
            assert_matches_type(ProductSearchResponse, product, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .session_create_quote_params import SessionCreateQuoteParams as SessionCreateQuoteParams
from .session_create_quote_response import SessionCreateQuoteResponse as SessionCreateQuoteResponse
from .session_list_products_response import SessionListProductsResponse as SessionListProductsResponse
from .session_confirm_checkout_params import SessionConfirmCheckoutParams as SessionConfirmCheckoutParams
from .session_confirm_checkout_response import SessionConfirmCheckoutResponse as SessionConfirmCheckoutResponse
from .session_retrieve_shipping_info_response import (
    SessionRetrieveShippingInfoResponse as SessionRetrieveShippingInfoResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["SessionRetrieveShippingInfoResponse", "Data", "DataShippingDetails"]


class DataShippingDetails(BaseModel):
    address_line1: str = FieldInfo(alias="addressLine1")
    """Address line 1"""

    city: str
    """City"""

    country_code: str = FieldInfo(alias="countryCode")
    """Country code"""

    email: str
    """Email"""

    full_name: str = FieldInfo(alias="fullName")
    """Full name"""

    phone_number: str = FieldInfo(alias="phoneNumber")
    """Phone number"""

    postal_code: str = FieldInfo(alias="postalCode")
    """Postal code"""

    state_or_province: str = FieldInfo(alias="stateOrProvince")
    """State or province"""

    address_line2: Optional[str] = FieldInfo(alias="addressLine2", default=None)
    """Address line 2"""


class Data(BaseModel):
    has_shipping: bool = FieldInfo(alias="hasShipping")

    shipping_details: Optional[DataShippingDetails] = FieldInfo(alias="shippingDetails", default=None)


class SessionRetrieveShippingInfoResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "ProductRetrieveDetailsResponse",
    "Data",
    "DataProductResults",
    "DataProductResultsStore",
    "DataProductResultsUserReview",
    "DataProductResultsVariant",
    "DataProductResultsVariantItem",
    "DataRelatedSearch",
]


class DataProductResultsStore(BaseModel):
    link: str

    name: str

    price: str

    shipping: str

    total: str


class DataProductResultsUserReview(BaseModel):
    rating: float

    source: str

    text: str

    title: str

    user_name: str = FieldInfo(alias="userName")


class DataProductResultsVariantItem(BaseModel):
    name: str

    available: Optional[bool] = None

    selected: Optional[bool] = None


class DataProductResultsVariant(BaseModel):
    items: List[DataProductResultsVariantItem]

    title: str


class DataProductResults(BaseModel):
    brand: str

    rating: float

    reviews: float

    stores: List[DataProductResultsStore]

    thumbnails: List[str]

    title: str

    user_reviews: List[DataProductResultsUserReview] = FieldInfo(alias="userReviews")

    variants: List[DataProductResultsVariant]


class DataRelatedSearch(BaseModel):
    link: str

    query: str

    image: Optional[str] = None


class Data(BaseModel):
    product_results: DataProductResults = FieldInfo(alias="productResults")

    related_searches: List[DataRelatedSearch] = FieldInfo(alias="relatedSearches")


class ProductRetrieveDetailsResponse(BaseModel):
    data: Data

    message: str

    status: str

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OrderRetrieveStatusResponse", "Data", "DataProduct", "DataShippingDetails"]


class DataProduct(BaseModel):
    product_name: str = FieldInfo(alias="productName")

    quantity: float

    product_metadata: Optional[Dict[str, object]] = FieldInfo(alias="productMetadata", default=None)


class DataShippingDetails(BaseModel):
    address_line1: str = FieldInfo(alias="addressLine1")

    city: str

    country_code: str = FieldInfo(alias="countryCode")

    email: str

    full_name: str = FieldInfo(alias="fullName")

    phone_number: str = FieldInfo(alias="phoneNumber")

    postal_code: str = FieldInfo(alias="postalCode")

    state_or_province: str = FieldInfo(alias="stateOrProvince")

    address_line2: Optional[str] = FieldInfo(alias="addressLine2", default=None)


class Data(BaseModel):
    id: str

    currency: str

    grand_total: str = FieldInfo(alias="grandTotal")

    products: List[DataProduct]

    shipping: str

    status: str

    status_message: str = FieldInfo(alias="statusMessage")

    subtotal: str

    tax: str

    user_id: str = FieldInfo(alias="userId")

    shipping_details: Optional[DataShippingDetails] = FieldInfo(alias="shippingDetails", default=None)


class OrderRetrieveStatusResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



from __future__ import annotations

from typing import Generic, TypeVar, cast

from henry_sdk._utils import extract_type_var_from_base

_T = TypeVar("_T")
_T2 = TypeVar("_T2")
_T3 = TypeVar("_T3")


class BaseGeneric(Generic[_T]): ...


class SubclassGeneric(BaseGeneric[_T]): ...


class BaseGenericMultipleTypeArgs(Generic[_T, _T2, _T3]): ...


class SubclassGenericMultipleTypeArgs(BaseGenericMultipleTypeArgs[_T, _T2, _T3]): ...


class SubclassDifferentOrderGenericMultipleTypeArgs(BaseGenericMultipleTypeArgs[_T2, _T, _T3]): ...


def test_extract_type_var() -> None:
    assert (
        extract_type_var_from_base(
            BaseGeneric[int],
            index=0,
            generic_bases=cast("tuple[type, ...]", (BaseGeneric,)),
        )
        == int
    )


def test_extract_type_var_generic_subclass() -> None:
    assert (
        extract_type_var_from_base(
            SubclassGeneric[int],
            index=0,
            generic_bases=cast("tuple[type, ...]", (BaseGeneric,)),
        )
        == int
    )


def test_extract_type_var_multiple() -> None:
    typ = BaseGenericMultipleTypeArgs[int, str, None]

    generic_bases = cast("tuple[type, ...]", (BaseGenericMultipleTypeArgs,))
    assert extract_type_var_from_base(typ, index=0, generic_bases=generic_bases) == int
    assert extract_type_var_from_base(typ, index=1, generic_bases=generic_bases) == str
    assert extract_type_var_from_base(typ, index=2, generic_bases=generic_bases) == type(None)


def test_extract_type_var_generic_subclass_multiple() -> None:
    typ = SubclassGenericMultipleTypeArgs[int, str, None]

    generic_bases = cast("tuple[type, ...]", (BaseGenericMultipleTypeArgs,))
    assert extract_type_var_from_base(typ, index=0, generic_bases=generic_bases) == int
    assert extract_type_var_from_base(typ, index=1, generic_bases=generic_bases) == str
    assert extract_type_var_from_base(typ, index=2, generic_bases=generic_bases) == type(None)


def test_extract_type_var_generic_subclass_different_ordering_multiple() -> None:
    typ = SubclassDifferentOrderGenericMultipleTypeArgs[int, str, None]

    generic_bases = cast("tuple[type, ...]", (BaseGenericMultipleTypeArgs,))
    assert extract_type_var_from_base(typ, index=0, generic_bases=generic_bases) == int
    assert extract_type_var_from_base(typ, index=1, generic_bases=generic_bases) == str
    assert extract_type_var_from_base(typ, index=2, generic_bases=generic_bases) == type(None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ProductSearchParams"]


class ProductSearchParams(TypedDict, total=False):
    query: Required[str]
    """Search query"""

    color: str
    """Color"""

    gender: str
    """Gender"""

    greater_than_price: Annotated[float, PropertyInfo(alias="greaterThanPrice")]
    """Greater than price"""

    limit: int
    """Limit the number of results"""

    lower_than_price: Annotated[float, PropertyInfo(alias="lowerThanPrice")]
    """Lower than price"""

    manufacturer: str
    """Manufacturer"""

    region: str
    """Region"""

    size: str
    """Size"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .session import (
    SessionResource,
    AsyncSessionResource,
    SessionResourceWithRawResponse,
    AsyncSessionResourceWithRawResponse,
    SessionResourceWithStreamingResponse,
    AsyncSessionResourceWithStreamingResponse,
)
from .checkout import (
    CheckoutResource,
    AsyncCheckoutResource,
    CheckoutResourceWithRawResponse,
    AsyncCheckoutResourceWithRawResponse,
    CheckoutResourceWithStreamingResponse,
    AsyncCheckoutResourceWithStreamingResponse,
)

__all__ = [
    "SessionResource",
    "AsyncSessionResource",
    "SessionResourceWithRawResponse",
    "AsyncSessionResourceWithRawResponse",
    "SessionResourceWithStreamingResponse",
    "AsyncSessionResourceWithStreamingResponse",
    "CheckoutResource",
    "AsyncCheckoutResource",
    "CheckoutResourceWithRawResponse",
    "AsyncCheckoutResourceWithRawResponse",
    "CheckoutResourceWithStreamingResponse",
    "AsyncCheckoutResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.cart import item_add_params
from ..._base_client import make_request_options
from ...types.cart.item_add_response import ItemAddResponse
from ...types.cart.item_list_response import ItemListResponse
from ...types.cart.item_clear_response import ItemClearResponse
from ...types.cart.item_remove_response import ItemRemoveResponse

__all__ = ["ItemsResource", "AsyncItemsResource"]


class ItemsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ItemsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return ItemsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ItemsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return ItemsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemListResponse:
        """
        Get all products from the cart

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._get(
            "/cart/items",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemListResponse,
        )

    def add(
        self,
        *,
        products_details: Iterable[item_add_params.ProductsDetail],
        x_user_id: str,
        check_variant_availability: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemAddResponse:
        """
        Adds product data to existing cart or create a new one.

        Args:
          check_variant_availability: Whether to check variant availability after adding to cart. If true, variant
              check requests will be created for products with metadata and requestIds
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._post(
            "/cart/items",
            body=maybe_transform(
                {
                    "products_details": products_details,
                    "check_variant_availability": check_variant_availability,
                },
                item_add_params.ItemAddParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemAddResponse,
        )

    def clear(
        self,
        *,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemClearResponse:
        """
        Delete all products from the cart

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._delete(
            "/cart/items",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemClearResponse,
        )

    def remove(
        self,
        product_id: str,
        *,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemRemoveResponse:
        """
        Delete a product from the cart

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not product_id:
            raise ValueError(f"Expected a non-empty value for `product_id` but received {product_id!r}")
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._delete(
            f"/cart/items/{product_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemRemoveResponse,
        )


class AsyncItemsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncItemsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncItemsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncItemsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncItemsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemListResponse:
        """
        Get all products from the cart

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._get(
            "/cart/items",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemListResponse,
        )

    async def add(
        self,
        *,
        products_details: Iterable[item_add_params.ProductsDetail],
        x_user_id: str,
        check_variant_availability: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemAddResponse:
        """
        Adds product data to existing cart or create a new one.

        Args:
          check_variant_availability: Whether to check variant availability after adding to cart. If true, variant
              check requests will be created for products with metadata and requestIds
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._post(
            "/cart/items",
            body=await async_maybe_transform(
                {
                    "products_details": products_details,
                    "check_variant_availability": check_variant_availability,
                },
                item_add_params.ItemAddParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemAddResponse,
        )

    async def clear(
        self,
        *,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemClearResponse:
        """
        Delete all products from the cart

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._delete(
            "/cart/items",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemClearResponse,
        )

    async def remove(
        self,
        product_id: str,
        *,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ItemRemoveResponse:
        """
        Delete a product from the cart

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not product_id:
            raise ValueError(f"Expected a non-empty value for `product_id` but received {product_id!r}")
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._delete(
            f"/cart/items/{product_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ItemRemoveResponse,
        )


class ItemsResourceWithRawResponse:
    def __init__(self, items: ItemsResource) -> None:
        self._items = items

        self.list = to_raw_response_wrapper(
            items.list,
        )
        self.add = to_raw_response_wrapper(
            items.add,
        )
        self.clear = to_raw_response_wrapper(
            items.clear,
        )
        self.remove = to_raw_response_wrapper(
            items.remove,
        )


class AsyncItemsResourceWithRawResponse:
    def __init__(self, items: AsyncItemsResource) -> None:
        self._items = items

        self.list = async_to_raw_response_wrapper(
            items.list,
        )
        self.add = async_to_raw_response_wrapper(
            items.add,
        )
        self.clear = async_to_raw_response_wrapper(
            items.clear,
        )
        self.remove = async_to_raw_response_wrapper(
            items.remove,
        )


class ItemsResourceWithStreamingResponse:
    def __init__(self, items: ItemsResource) -> None:
        self._items = items

        self.list = to_streamed_response_wrapper(
            items.list,
        )
        self.add = to_streamed_response_wrapper(
            items.add,
        )
        self.clear = to_streamed_response_wrapper(
            items.clear,
        )
        self.remove = to_streamed_response_wrapper(
            items.remove,
        )


class AsyncItemsResourceWithStreamingResponse:
    def __init__(self, items: AsyncItemsResource) -> None:
        self._items = items

        self.list = async_to_streamed_response_wrapper(
            items.list,
        )
        self.add = async_to_streamed_response_wrapper(
            items.add,
        )
        self.clear = async_to_streamed_response_wrapper(
            items.clear,
        )
        self.remove = async_to_streamed_response_wrapper(
            items.remove,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["MerchantCheckStatusResponse", "Data"]


class Data(BaseModel):
    merchant_support_status: bool = FieldInfo(alias="merchantSupportStatus")


class MerchantCheckStatusResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["WalletCreateCardCollectionResponse", "Data"]


class Data(BaseModel):
    modal_url: str


class WalletCreateCardCollectionResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["VariantCheckRetrieveStatusResponse", "Data", "DataStockStatus", "DataStockStatusDetails"]


class DataStockStatusDetails(BaseModel):
    found: bool

    in_stock: bool = FieldInfo(alias="inStock")

    value: str

    actual_value: Optional[str] = FieldInfo(alias="actualValue", default=None)


class DataStockStatus(BaseModel):
    available: bool

    details: Dict[str, DataStockStatusDetails]

    message: str


class Data(BaseModel):
    api_version: str = FieldInfo(alias="apiVersion")

    execution_time: str = FieldInfo(alias="executionTime")

    product_name: str = FieldInfo(alias="productName")

    requested_variant: Dict[str, str] = FieldInfo(alias="requestedVariant")

    request_time: str = FieldInfo(alias="requestTime")

    stock_status: DataStockStatus = FieldInfo(alias="stockStatus")

    timestamp: str

    total_execution_time: str = FieldInfo(alias="totalExecutionTime")

    url: str


class VariantCheckRetrieveStatusResponse(BaseModel):
    created_at: str = FieldInfo(alias="createdAt")

    message: str

    request_id: str = FieldInfo(alias="requestId")

    status: Literal["pending", "processing", "completed", "failed", "timeout"]

    success: bool

    updated_at: str = FieldInfo(alias="updatedAt")

    completed_at: Optional[str] = FieldInfo(alias="completedAt", default=None)

    data: Optional[Data] = None

    error_message: Optional[str] = FieldInfo(alias="errorMessage", default=None)

    execution_time_ms: Optional[float] = FieldInfo(alias="executionTimeMs", default=None)

    product_link: Optional[str] = FieldInfo(alias="productLink", default=None)

    requested_variant: Optional[Dict[str, str]] = FieldInfo(alias="requestedVariant", default=None)

    scraper_status_code: Optional[float] = FieldInfo(alias="scraperStatusCode", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["MerchantListSupportedParams"]


class MerchantListSupportedParams(TypedDict, total=False):
    limit: int
    """Number of items per page (1-100)"""

    page: int
    """Page number (starts from 1)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from henry_sdk import HenrySDK, AsyncHenrySDK
from tests.utils import assert_matches_type
from henry_sdk.types.checkout import (
    SessionCreateQuoteResponse,
    SessionListProductsResponse,
    SessionConfirmCheckoutResponse,
    SessionRetrieveShippingInfoResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSession:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_confirm_checkout(self, client: HenrySDK) -> None:
        session = client.checkout.session.confirm_checkout(
            x_session_token="x-session-token",
        )
        assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_confirm_checkout_with_all_params(self, client: HenrySDK) -> None:
        session = client.checkout.session.confirm_checkout(
            x_session_token="x-session-token",
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
                "address_line2": "Apt 1",
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_confirm_checkout(self, client: HenrySDK) -> None:
        response = client.checkout.session.with_raw_response.confirm_checkout(
            x_session_token="x-session-token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = response.parse()
        assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_confirm_checkout(self, client: HenrySDK) -> None:
        with client.checkout.session.with_streaming_response.confirm_checkout(
            x_session_token="x-session-token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = response.parse()
            assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_quote(self, client: HenrySDK) -> None:
        session = client.checkout.session.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_quote_with_all_params(self, client: HenrySDK) -> None:
        session = client.checkout.session.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
                "address_line2": "Apt 1",
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_quote(self, client: HenrySDK) -> None:
        response = client.checkout.session.with_raw_response.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
            },
            x_user_id="x-user-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = response.parse()
        assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_quote(self, client: HenrySDK) -> None:
        with client.checkout.session.with_streaming_response.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
            },
            x_user_id="x-user-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = response.parse()
            assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_products(self, client: HenrySDK) -> None:
        session = client.checkout.session.list_products(
            x_session_token="x-session-token",
        )
        assert_matches_type(SessionListProductsResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_products(self, client: HenrySDK) -> None:
        response = client.checkout.session.with_raw_response.list_products(
            x_session_token="x-session-token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = response.parse()
        assert_matches_type(SessionListProductsResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_products(self, client: HenrySDK) -> None:
        with client.checkout.session.with_streaming_response.list_products(
            x_session_token="x-session-token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = response.parse()
            assert_matches_type(SessionListProductsResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_shipping_info(self, client: HenrySDK) -> None:
        session = client.checkout.session.retrieve_shipping_info()
        assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_shipping_info_with_all_params(self, client: HenrySDK) -> None:
        session = client.checkout.session.retrieve_shipping_info(
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_shipping_info(self, client: HenrySDK) -> None:
        response = client.checkout.session.with_raw_response.retrieve_shipping_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = response.parse()
        assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_shipping_info(self, client: HenrySDK) -> None:
        with client.checkout.session.with_streaming_response.retrieve_shipping_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = response.parse()
            assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSession:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_confirm_checkout(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.confirm_checkout(
            x_session_token="x-session-token",
        )
        assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_confirm_checkout_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.confirm_checkout(
            x_session_token="x-session-token",
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
                "address_line2": "Apt 1",
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_confirm_checkout(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.checkout.session.with_raw_response.confirm_checkout(
            x_session_token="x-session-token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = await response.parse()
        assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_confirm_checkout(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.checkout.session.with_streaming_response.confirm_checkout(
            x_session_token="x-session-token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = await response.parse()
            assert_matches_type(SessionConfirmCheckoutResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_quote(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_quote_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
                "address_line2": "Apt 1",
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_quote(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.checkout.session.with_raw_response.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
            },
            x_user_id="x-user-id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = await response.parse()
        assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_quote(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.checkout.session.with_streaming_response.create_quote(
            shipping_details={
                "address_line1": "350 5th Ave",
                "city": "New York",
                "country_code": "US",
                "email": "john.doe@example.com",
                "full_name": "John Doe",
                "phone_number": "+1234567890",
                "postal_code": "10001",
                "state_or_province": "New York",
            },
            x_user_id="x-user-id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = await response.parse()
            assert_matches_type(SessionCreateQuoteResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_products(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.list_products(
            x_session_token="x-session-token",
        )
        assert_matches_type(SessionListProductsResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_products(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.checkout.session.with_raw_response.list_products(
            x_session_token="x-session-token",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = await response.parse()
        assert_matches_type(SessionListProductsResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_products(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.checkout.session.with_streaming_response.list_products(
            x_session_token="x-session-token",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = await response.parse()
            assert_matches_type(SessionListProductsResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_shipping_info(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.retrieve_shipping_info()
        assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_shipping_info_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        session = await async_client.checkout.session.retrieve_shipping_info(
            x_user_id="x-user-id",
        )
        assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_shipping_info(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.checkout.session.with_raw_response.retrieve_shipping_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        session = await response.parse()
        assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_shipping_info(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.checkout.session.with_streaming_response.retrieve_shipping_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            session = await response.parse()
            assert_matches_type(SessionRetrieveShippingInfoResponse, session, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import merchant_check_status_params, merchant_list_supported_params, merchant_get_shipping_info_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.merchant_check_status_response import MerchantCheckStatusResponse
from ..types.merchant_list_supported_response import MerchantListSupportedResponse
from ..types.merchant_get_shipping_info_response import MerchantGetShippingInfoResponse

__all__ = ["MerchantsResource", "AsyncMerchantsResource"]


class MerchantsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MerchantsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return MerchantsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MerchantsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return MerchantsResourceWithStreamingResponse(self)

    def check_status(
        self,
        merchant_domain: str,
        *,
        checkout_mode: Literal["allowlist", "blocklist"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MerchantCheckStatusResponse:
        """
        Verifies whether a merchant is supported by checking their domain

        Args:
          merchant_domain: Merchant Domain

          checkout_mode: Checkout mode to check merchant support against. 'allowlist' only allows
              explicitly approved merchants, 'blocklist' allows all except explicitly blocked
              merchants.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not merchant_domain:
            raise ValueError(f"Expected a non-empty value for `merchant_domain` but received {merchant_domain!r}")
        return self._get(
            f"/merchants/{merchant_domain}/status",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"checkout_mode": checkout_mode}, merchant_check_status_params.MerchantCheckStatusParams
                ),
            ),
            cast_to=MerchantCheckStatusResponse,
        )

    def get_shipping_info(
        self,
        *,
        domain: str | Omit = omit,
        limit: int | Omit = omit,
        merchant_id: str | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MerchantGetShippingInfoResponse:
        """
        Retrieve shipping information including shipping tiers and free shipping
        thresholds for merchants

        Args:
          domain: Merchant domain to filter by

          limit: Number of items per page (1-100)

          merchant_id: Merchant ID to filter by

          offset: Number of items to skip

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/merchants/shipping-info",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "domain": domain,
                        "limit": limit,
                        "merchant_id": merchant_id,
                        "offset": offset,
                    },
                    merchant_get_shipping_info_params.MerchantGetShippingInfoParams,
                ),
            ),
            cast_to=MerchantGetShippingInfoResponse,
        )

    def list_supported(
        self,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MerchantListSupportedResponse:
        """
        Returns a list of allowlist supported merchants

        Args:
          limit: Number of items per page (1-100)

          page: Page number (starts from 1)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/merchants/list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    merchant_list_supported_params.MerchantListSupportedParams,
                ),
            ),
            cast_to=MerchantListSupportedResponse,
        )


class AsyncMerchantsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMerchantsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncMerchantsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMerchantsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncMerchantsResourceWithStreamingResponse(self)

    async def check_status(
        self,
        merchant_domain: str,
        *,
        checkout_mode: Literal["allowlist", "blocklist"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MerchantCheckStatusResponse:
        """
        Verifies whether a merchant is supported by checking their domain

        Args:
          merchant_domain: Merchant Domain

          checkout_mode: Checkout mode to check merchant support against. 'allowlist' only allows
              explicitly approved merchants, 'blocklist' allows all except explicitly blocked
              merchants.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not merchant_domain:
            raise ValueError(f"Expected a non-empty value for `merchant_domain` but received {merchant_domain!r}")
        return await self._get(
            f"/merchants/{merchant_domain}/status",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"checkout_mode": checkout_mode}, merchant_check_status_params.MerchantCheckStatusParams
                ),
            ),
            cast_to=MerchantCheckStatusResponse,
        )

    async def get_shipping_info(
        self,
        *,
        domain: str | Omit = omit,
        limit: int | Omit = omit,
        merchant_id: str | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MerchantGetShippingInfoResponse:
        """
        Retrieve shipping information including shipping tiers and free shipping
        thresholds for merchants

        Args:
          domain: Merchant domain to filter by

          limit: Number of items per page (1-100)

          merchant_id: Merchant ID to filter by

          offset: Number of items to skip

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/merchants/shipping-info",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "domain": domain,
                        "limit": limit,
                        "merchant_id": merchant_id,
                        "offset": offset,
                    },
                    merchant_get_shipping_info_params.MerchantGetShippingInfoParams,
                ),
            ),
            cast_to=MerchantGetShippingInfoResponse,
        )

    async def list_supported(
        self,
        *,
        limit: int | Omit = omit,
        page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MerchantListSupportedResponse:
        """
        Returns a list of allowlist supported merchants

        Args:
          limit: Number of items per page (1-100)

          page: Page number (starts from 1)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/merchants/list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    merchant_list_supported_params.MerchantListSupportedParams,
                ),
            ),
            cast_to=MerchantListSupportedResponse,
        )


class MerchantsResourceWithRawResponse:
    def __init__(self, merchants: MerchantsResource) -> None:
        self._merchants = merchants

        self.check_status = to_raw_response_wrapper(
            merchants.check_status,
        )
        self.get_shipping_info = to_raw_response_wrapper(
            merchants.get_shipping_info,
        )
        self.list_supported = to_raw_response_wrapper(
            merchants.list_supported,
        )


class AsyncMerchantsResourceWithRawResponse:
    def __init__(self, merchants: AsyncMerchantsResource) -> None:
        self._merchants = merchants

        self.check_status = async_to_raw_response_wrapper(
            merchants.check_status,
        )
        self.get_shipping_info = async_to_raw_response_wrapper(
            merchants.get_shipping_info,
        )
        self.list_supported = async_to_raw_response_wrapper(
            merchants.list_supported,
        )


class MerchantsResourceWithStreamingResponse:
    def __init__(self, merchants: MerchantsResource) -> None:
        self._merchants = merchants

        self.check_status = to_streamed_response_wrapper(
            merchants.check_status,
        )
        self.get_shipping_info = to_streamed_response_wrapper(
            merchants.get_shipping_info,
        )
        self.list_supported = to_streamed_response_wrapper(
            merchants.list_supported,
        )


class AsyncMerchantsResourceWithStreamingResponse:
    def __init__(self, merchants: AsyncMerchantsResource) -> None:
        self._merchants = merchants

        self.check_status = async_to_streamed_response_wrapper(
            merchants.check_status,
        )
        self.get_shipping_info = async_to_streamed_response_wrapper(
            merchants.get_shipping_info,
        )
        self.list_supported = async_to_streamed_response_wrapper(
            merchants.list_supported,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .variant_check_create_params import VariantCheckCreateParams as VariantCheckCreateParams
from .variant_check_create_response import VariantCheckCreateResponse as VariantCheckCreateResponse
from .variant_check_retrieve_status_response import (
    VariantCheckRetrieveStatusResponse as VariantCheckRetrieveStatusResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import wallet_create_card_collection_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.wallet_create_card_collection_response import WalletCreateCardCollectionResponse

__all__ = ["WalletResource", "AsyncWalletResource"]


class WalletResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> WalletResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return WalletResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WalletResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return WalletResourceWithStreamingResponse(self)

    def create_card_collection(
        self,
        *,
        x_user_id: str,
        auth: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> WalletCreateCardCollectionResponse:
        """Returns a modal URL for users to save payment cards.

        Supports both authenticated
        and guest card collection

        Args:
          auth: Whether authentication is required for card collection (default: true)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._post(
            "/wallet/card-collect",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"auth": auth}, wallet_create_card_collection_params.WalletCreateCardCollectionParams
                ),
            ),
            cast_to=WalletCreateCardCollectionResponse,
        )


class AsyncWalletResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncWalletResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncWalletResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWalletResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncWalletResourceWithStreamingResponse(self)

    async def create_card_collection(
        self,
        *,
        x_user_id: str,
        auth: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> WalletCreateCardCollectionResponse:
        """Returns a modal URL for users to save payment cards.

        Supports both authenticated
        and guest card collection

        Args:
          auth: Whether authentication is required for card collection (default: true)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._post(
            "/wallet/card-collect",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"auth": auth}, wallet_create_card_collection_params.WalletCreateCardCollectionParams
                ),
            ),
            cast_to=WalletCreateCardCollectionResponse,
        )


class WalletResourceWithRawResponse:
    def __init__(self, wallet: WalletResource) -> None:
        self._wallet = wallet

        self.create_card_collection = to_raw_response_wrapper(
            wallet.create_card_collection,
        )


class AsyncWalletResourceWithRawResponse:
    def __init__(self, wallet: AsyncWalletResource) -> None:
        self._wallet = wallet

        self.create_card_collection = async_to_raw_response_wrapper(
            wallet.create_card_collection,
        )


class WalletResourceWithStreamingResponse:
    def __init__(self, wallet: WalletResource) -> None:
        self._wallet = wallet

        self.create_card_collection = to_streamed_response_wrapper(
            wallet.create_card_collection,
        )


class AsyncWalletResourceWithStreamingResponse:
    def __init__(self, wallet: AsyncWalletResource) -> None:
        self._wallet = wallet

        self.create_card_collection = async_to_streamed_response_wrapper(
            wallet.create_card_collection,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["CartCreateCheckoutParams"]


class CartCreateCheckoutParams(TypedDict, total=False):
    x_user_id: Required[Annotated[str, PropertyInfo(alias="x-user-id")]]

    auth: bool
    """Whether authentication is required for checkout (default: true)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from henry_sdk import HenrySDK, AsyncHenrySDK
from tests.utils import assert_matches_type
from henry_sdk.types.products import (
    VariantCheckCreateResponse,
    VariantCheckRetrieveStatusResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestVariantCheck:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: HenrySDK) -> None:
        variant_check = client.products.variant_check.create(
            product={},
        )
        assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: HenrySDK) -> None:
        variant_check = client.products.variant_check.create(
            product={
                "affiliate_product_link": "https://www.on.com/en-us/products/cloud-6-versa-m-3mf1004/mens/black-eclipse-shoes-3MF10040106?ref=affiliate123",
                "metadata": {
                    "color": "Black",
                    "size": "9",
                },
                "name": "Men's Cloud 6 Versa Shoes",
                "price": "100",
                "product_id": "P01145AC2",
                "product_image_link": "https://images.ctfassets.net/hnk2vsx53n6l/2xi62H2BswFpVK0SjUmhXM/0d4a4bb14915c9a5d3228df45c774629/c36d3fd00cf91ec9fb5ff4bc4d4a0093cccbe8cd.png?w=192&h=192&fm=avif&f=center&fit=fill&q=80",
                "product_link": "https://www.on.com/en-us/products/cloud-6-versa-m-3mf1004/mens/black-eclipse-shoes-3MF10040106",
                "quantity": 1,
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: HenrySDK) -> None:
        response = client.products.variant_check.with_raw_response.create(
            product={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        variant_check = response.parse()
        assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: HenrySDK) -> None:
        with client.products.variant_check.with_streaming_response.create(
            product={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            variant_check = response.parse()
            assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_status(self, client: HenrySDK) -> None:
        variant_check = client.products.variant_check.retrieve_status(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(VariantCheckRetrieveStatusResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_status(self, client: HenrySDK) -> None:
        response = client.products.variant_check.with_raw_response.retrieve_status(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        variant_check = response.parse()
        assert_matches_type(VariantCheckRetrieveStatusResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_status(self, client: HenrySDK) -> None:
        with client.products.variant_check.with_streaming_response.retrieve_status(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            variant_check = response.parse()
            assert_matches_type(VariantCheckRetrieveStatusResponse, variant_check, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve_status(self, client: HenrySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.products.variant_check.with_raw_response.retrieve_status(
                "",
            )


class TestAsyncVariantCheck:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncHenrySDK) -> None:
        variant_check = await async_client.products.variant_check.create(
            product={},
        )
        assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        variant_check = await async_client.products.variant_check.create(
            product={
                "affiliate_product_link": "https://www.on.com/en-us/products/cloud-6-versa-m-3mf1004/mens/black-eclipse-shoes-3MF10040106?ref=affiliate123",
                "metadata": {
                    "color": "Black",
                    "size": "9",
                },
                "name": "Men's Cloud 6 Versa Shoes",
                "price": "100",
                "product_id": "P01145AC2",
                "product_image_link": "https://images.ctfassets.net/hnk2vsx53n6l/2xi62H2BswFpVK0SjUmhXM/0d4a4bb14915c9a5d3228df45c774629/c36d3fd00cf91ec9fb5ff4bc4d4a0093cccbe8cd.png?w=192&h=192&fm=avif&f=center&fit=fill&q=80",
                "product_link": "https://www.on.com/en-us/products/cloud-6-versa-m-3mf1004/mens/black-eclipse-shoes-3MF10040106",
                "quantity": 1,
            },
            x_user_id="x-user-id",
        )
        assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.products.variant_check.with_raw_response.create(
            product={},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        variant_check = await response.parse()
        assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.products.variant_check.with_streaming_response.create(
            product={},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            variant_check = await response.parse()
            assert_matches_type(VariantCheckCreateResponse, variant_check, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_status(self, async_client: AsyncHenrySDK) -> None:
        variant_check = await async_client.products.variant_check.retrieve_status(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(VariantCheckRetrieveStatusResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_status(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.products.variant_check.with_raw_response.retrieve_status(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        variant_check = await response.parse()
        assert_matches_type(VariantCheckRetrieveStatusResponse, variant_check, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_status(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.products.variant_check.with_streaming_response.retrieve_status(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            variant_check = await response.parse()
            assert_matches_type(VariantCheckRetrieveStatusResponse, variant_check, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve_status(self, async_client: AsyncHenrySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.products.variant_check.with_raw_response.retrieve_status(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["MerchantGetShippingInfoResponse", "Data", "DataMerchant", "DataMerchantShippingTier"]


class DataMerchantShippingTier(BaseModel):
    id: str

    cost: float

    estimated_delivery_max_days: Optional[float] = FieldInfo(alias="estimatedDeliveryMaxDays", default=None)

    estimated_delivery_min_days: Optional[float] = FieldInfo(alias="estimatedDeliveryMinDays", default=None)

    tier_name: str = FieldInfo(alias="tierName")


class DataMerchant(BaseModel):
    id: str

    display_name: Optional[str] = FieldInfo(alias="displayName", default=None)

    domain: str

    free_shipping_threshold: Optional[float] = FieldInfo(alias="freeShippingThreshold", default=None)

    name: str

    shipping_notes: Optional[str] = FieldInfo(alias="shippingNotes", default=None)

    shipping_tiers: List[DataMerchantShippingTier] = FieldInfo(alias="shippingTiers")


class Data(BaseModel):
    has_more: bool = FieldInfo(alias="hasMore")

    merchants: List[DataMerchant]

    total_count: float = FieldInfo(alias="totalCount")


class MerchantGetShippingInfoResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from ..._models import BaseModel

__all__ = ["SessionCreateQuoteResponse", "Data", "DataOrderMetadata"]


class DataOrderMetadata(BaseModel):
    shipping: Dict[str, Optional[float]]

    shipping_total: float

    tax: float

    total_price: float


class Data(BaseModel):
    order_metadata: DataOrderMetadata

    session_token: str


class SessionCreateQuoteResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...types import product_search_params, product_retrieve_details_params
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .variant_check import (
    VariantCheckResource,
    AsyncVariantCheckResource,
    VariantCheckResourceWithRawResponse,
    AsyncVariantCheckResourceWithRawResponse,
    VariantCheckResourceWithStreamingResponse,
    AsyncVariantCheckResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from ...types.product_search_response import ProductSearchResponse
from ...types.product_retrieve_details_response import ProductRetrieveDetailsResponse

__all__ = ["ProductsResource", "AsyncProductsResource"]


class ProductsResource(SyncAPIResource):
    @cached_property
    def variant_check(self) -> VariantCheckResource:
        return VariantCheckResource(self._client)

    @cached_property
    def with_raw_response(self) -> ProductsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return ProductsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProductsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return ProductsResourceWithStreamingResponse(self)

    def retrieve_details(
        self,
        *,
        product_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductRetrieveDetailsResponse:
        """
        Retrieve detailed information about a specific product given product ID

        Args:
          product_id: Product ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/products/details",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"product_id": product_id}, product_retrieve_details_params.ProductRetrieveDetailsParams
                ),
            ),
            cast_to=ProductRetrieveDetailsResponse,
        )

    def search(
        self,
        *,
        query: str,
        color: str | Omit = omit,
        gender: str | Omit = omit,
        greater_than_price: float | Omit = omit,
        limit: int | Omit = omit,
        lower_than_price: float | Omit = omit,
        manufacturer: str | Omit = omit,
        region: str | Omit = omit,
        size: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductSearchResponse:
        """
        Search for products using keyword and passing various filters and criteria

        Args:
          query: Search query

          color: Color

          gender: Gender

          greater_than_price: Greater than price

          limit: Limit the number of results

          lower_than_price: Lower than price

          manufacturer: Manufacturer

          region: Region

          size: Size

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/products/search",
            body=maybe_transform(
                {
                    "query": query,
                    "color": color,
                    "gender": gender,
                    "greater_than_price": greater_than_price,
                    "limit": limit,
                    "lower_than_price": lower_than_price,
                    "manufacturer": manufacturer,
                    "region": region,
                    "size": size,
                },
                product_search_params.ProductSearchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductSearchResponse,
        )


class AsyncProductsResource(AsyncAPIResource):
    @cached_property
    def variant_check(self) -> AsyncVariantCheckResource:
        return AsyncVariantCheckResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncProductsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncProductsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProductsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncProductsResourceWithStreamingResponse(self)

    async def retrieve_details(
        self,
        *,
        product_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductRetrieveDetailsResponse:
        """
        Retrieve detailed information about a specific product given product ID

        Args:
          product_id: Product ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/products/details",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"product_id": product_id}, product_retrieve_details_params.ProductRetrieveDetailsParams
                ),
            ),
            cast_to=ProductRetrieveDetailsResponse,
        )

    async def search(
        self,
        *,
        query: str,
        color: str | Omit = omit,
        gender: str | Omit = omit,
        greater_than_price: float | Omit = omit,
        limit: int | Omit = omit,
        lower_than_price: float | Omit = omit,
        manufacturer: str | Omit = omit,
        region: str | Omit = omit,
        size: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductSearchResponse:
        """
        Search for products using keyword and passing various filters and criteria

        Args:
          query: Search query

          color: Color

          gender: Gender

          greater_than_price: Greater than price

          limit: Limit the number of results

          lower_than_price: Lower than price

          manufacturer: Manufacturer

          region: Region

          size: Size

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/products/search",
            body=await async_maybe_transform(
                {
                    "query": query,
                    "color": color,
                    "gender": gender,
                    "greater_than_price": greater_than_price,
                    "limit": limit,
                    "lower_than_price": lower_than_price,
                    "manufacturer": manufacturer,
                    "region": region,
                    "size": size,
                },
                product_search_params.ProductSearchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductSearchResponse,
        )


class ProductsResourceWithRawResponse:
    def __init__(self, products: ProductsResource) -> None:
        self._products = products

        self.retrieve_details = to_raw_response_wrapper(
            products.retrieve_details,
        )
        self.search = to_raw_response_wrapper(
            products.search,
        )

    @cached_property
    def variant_check(self) -> VariantCheckResourceWithRawResponse:
        return VariantCheckResourceWithRawResponse(self._products.variant_check)


class AsyncProductsResourceWithRawResponse:
    def __init__(self, products: AsyncProductsResource) -> None:
        self._products = products

        self.retrieve_details = async_to_raw_response_wrapper(
            products.retrieve_details,
        )
        self.search = async_to_raw_response_wrapper(
            products.search,
        )

    @cached_property
    def variant_check(self) -> AsyncVariantCheckResourceWithRawResponse:
        return AsyncVariantCheckResourceWithRawResponse(self._products.variant_check)


class ProductsResourceWithStreamingResponse:
    def __init__(self, products: ProductsResource) -> None:
        self._products = products

        self.retrieve_details = to_streamed_response_wrapper(
            products.retrieve_details,
        )
        self.search = to_streamed_response_wrapper(
            products.search,
        )

    @cached_property
    def variant_check(self) -> VariantCheckResourceWithStreamingResponse:
        return VariantCheckResourceWithStreamingResponse(self._products.variant_check)


class AsyncProductsResourceWithStreamingResponse:
    def __init__(self, products: AsyncProductsResource) -> None:
        self._products = products

        self.retrieve_details = async_to_streamed_response_wrapper(
            products.retrieve_details,
        )
        self.search = async_to_streamed_response_wrapper(
            products.search,
        )

    @cached_property
    def variant_check(self) -> AsyncVariantCheckResourceWithStreamingResponse:
        return AsyncVariantCheckResourceWithStreamingResponse(self._products.variant_check)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from henry_sdk import HenrySDK, AsyncHenrySDK
from tests.utils import assert_matches_type
from henry_sdk.types import (
    MerchantCheckStatusResponse,
    MerchantListSupportedResponse,
    MerchantGetShippingInfoResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMerchants:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_check_status(self, client: HenrySDK) -> None:
        merchant = client.merchants.check_status(
            merchant_domain="walmart.com",
        )
        assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_check_status_with_all_params(self, client: HenrySDK) -> None:
        merchant = client.merchants.check_status(
            merchant_domain="walmart.com",
            checkout_mode="allowlist",
        )
        assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_check_status(self, client: HenrySDK) -> None:
        response = client.merchants.with_raw_response.check_status(
            merchant_domain="walmart.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        merchant = response.parse()
        assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_check_status(self, client: HenrySDK) -> None:
        with client.merchants.with_streaming_response.check_status(
            merchant_domain="walmart.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            merchant = response.parse()
            assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_check_status(self, client: HenrySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `merchant_domain` but received ''"):
            client.merchants.with_raw_response.check_status(
                merchant_domain="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_shipping_info(self, client: HenrySDK) -> None:
        merchant = client.merchants.get_shipping_info()
        assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_shipping_info_with_all_params(self, client: HenrySDK) -> None:
        merchant = client.merchants.get_shipping_info(
            domain="domain",
            limit=1,
            merchant_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            offset=0,
        )
        assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_shipping_info(self, client: HenrySDK) -> None:
        response = client.merchants.with_raw_response.get_shipping_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        merchant = response.parse()
        assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_shipping_info(self, client: HenrySDK) -> None:
        with client.merchants.with_streaming_response.get_shipping_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            merchant = response.parse()
            assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_supported(self, client: HenrySDK) -> None:
        merchant = client.merchants.list_supported()
        assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_supported_with_all_params(self, client: HenrySDK) -> None:
        merchant = client.merchants.list_supported(
            limit=1,
            page=1,
        )
        assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_supported(self, client: HenrySDK) -> None:
        response = client.merchants.with_raw_response.list_supported()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        merchant = response.parse()
        assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_supported(self, client: HenrySDK) -> None:
        with client.merchants.with_streaming_response.list_supported() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            merchant = response.parse()
            assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncMerchants:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_check_status(self, async_client: AsyncHenrySDK) -> None:
        merchant = await async_client.merchants.check_status(
            merchant_domain="walmart.com",
        )
        assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_check_status_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        merchant = await async_client.merchants.check_status(
            merchant_domain="walmart.com",
            checkout_mode="allowlist",
        )
        assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_check_status(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.merchants.with_raw_response.check_status(
            merchant_domain="walmart.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        merchant = await response.parse()
        assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_check_status(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.merchants.with_streaming_response.check_status(
            merchant_domain="walmart.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            merchant = await response.parse()
            assert_matches_type(MerchantCheckStatusResponse, merchant, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_check_status(self, async_client: AsyncHenrySDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `merchant_domain` but received ''"):
            await async_client.merchants.with_raw_response.check_status(
                merchant_domain="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_shipping_info(self, async_client: AsyncHenrySDK) -> None:
        merchant = await async_client.merchants.get_shipping_info()
        assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_shipping_info_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        merchant = await async_client.merchants.get_shipping_info(
            domain="domain",
            limit=1,
            merchant_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            offset=0,
        )
        assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_shipping_info(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.merchants.with_raw_response.get_shipping_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        merchant = await response.parse()
        assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_shipping_info(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.merchants.with_streaming_response.get_shipping_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            merchant = await response.parse()
            assert_matches_type(MerchantGetShippingInfoResponse, merchant, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_supported(self, async_client: AsyncHenrySDK) -> None:
        merchant = await async_client.merchants.list_supported()
        assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_supported_with_all_params(self, async_client: AsyncHenrySDK) -> None:
        merchant = await async_client.merchants.list_supported(
            limit=1,
            page=1,
        )
        assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_supported(self, async_client: AsyncHenrySDK) -> None:
        response = await async_client.merchants.with_raw_response.list_supported()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        merchant = await response.parse()
        assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_supported(self, async_client: AsyncHenrySDK) -> None:
        async with async_client.merchants.with_streaming_response.list_supported() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            merchant = await response.parse()
            assert_matches_type(MerchantListSupportedResponse, merchant, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["MerchantCheckStatusParams"]


class MerchantCheckStatusParams(TypedDict, total=False):
    checkout_mode: Annotated[Literal["allowlist", "blocklist"], PropertyInfo(alias="checkoutMode")]
    """Checkout mode to check merchant support against.

    'allowlist' only allows explicitly approved merchants, 'blocklist' allows all
    except explicitly blocked merchants.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["ItemAddParams", "ProductsDetail"]


class ItemAddParams(TypedDict, total=False):
    products_details: Required[Annotated[Iterable[ProductsDetail], PropertyInfo(alias="productsDetails")]]

    x_user_id: Required[Annotated[str, PropertyInfo(alias="x-user-id")]]

    check_variant_availability: Annotated[bool, PropertyInfo(alias="checkVariantAvailability")]
    """Whether to check variant availability after adding to cart.

    If true, variant check requests will be created for products with metadata and
    requestIds returned.
    """


class ProductsDetail(TypedDict, total=False):
    name: Required[str]
    """Product name"""

    price: Required[str]
    """Product price"""

    product_link: Required[Annotated[str, PropertyInfo(alias="productLink")]]
    """Product link"""

    quantity: Required[float]
    """Quantity"""

    affiliate_product_link: Annotated[str, PropertyInfo(alias="affiliateProductLink")]
    """
    Affiliate product link (if provided, will be used instead of productLink for
    order fulfillment)
    """

    metadata: Dict[str, str]
    """Product metadata"""

    product_id: Annotated[str, PropertyInfo(alias="productId")]
    """Product Id"""

    product_image_link: Annotated[str, PropertyInfo(alias="productImageLink")]
    """Product image link (thumbnail)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.products import variant_check_create_params
from ...types.products.variant_check_create_response import VariantCheckCreateResponse
from ...types.products.variant_check_retrieve_status_response import VariantCheckRetrieveStatusResponse

__all__ = ["VariantCheckResource", "AsyncVariantCheckResource"]


class VariantCheckResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VariantCheckResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return VariantCheckResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VariantCheckResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return VariantCheckResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        product: variant_check_create_params.Product,
        x_user_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VariantCheckCreateResponse:
        """! _This endpoint is experimental and unstable.

        The API contract may change
        without notice._

        Creates a request to check if a specific product variant combination is in
        stock. Returns immediately with a request ID that can be used to poll for
        results.

        Args:
          product: Product details to check variant availability for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"x-user-id": x_user_id}), **(extra_headers or {})}
        return self._post(
            "/products/variant-check",
            body=maybe_transform({"product": product}, variant_check_create_params.VariantCheckCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VariantCheckCreateResponse,
        )

    def retrieve_status(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VariantCheckRetrieveStatusResponse:
        """! _This endpoint is experimental and unstable.

        The API contract may change
        without notice._

        Poll the status of a variant availability check request. Returns the current
        status and results if completed.

        Args:
          id: The variant check request ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/products/variant-check/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VariantCheckRetrieveStatusResponse,
        )


class AsyncVariantCheckResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVariantCheckResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncVariantCheckResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVariantCheckResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncVariantCheckResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        product: variant_check_create_params.Product,
        x_user_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VariantCheckCreateResponse:
        """! _This endpoint is experimental and unstable.

        The API contract may change
        without notice._

        Creates a request to check if a specific product variant combination is in
        stock. Returns immediately with a request ID that can be used to poll for
        results.

        Args:
          product: Product details to check variant availability for

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"x-user-id": x_user_id}), **(extra_headers or {})}
        return await self._post(
            "/products/variant-check",
            body=await async_maybe_transform(
                {"product": product}, variant_check_create_params.VariantCheckCreateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VariantCheckCreateResponse,
        )

    async def retrieve_status(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VariantCheckRetrieveStatusResponse:
        """! _This endpoint is experimental and unstable.

        The API contract may change
        without notice._

        Poll the status of a variant availability check request. Returns the current
        status and results if completed.

        Args:
          id: The variant check request ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/products/variant-check/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VariantCheckRetrieveStatusResponse,
        )


class VariantCheckResourceWithRawResponse:
    def __init__(self, variant_check: VariantCheckResource) -> None:
        self._variant_check = variant_check

        self.create = to_raw_response_wrapper(
            variant_check.create,
        )
        self.retrieve_status = to_raw_response_wrapper(
            variant_check.retrieve_status,
        )


class AsyncVariantCheckResourceWithRawResponse:
    def __init__(self, variant_check: AsyncVariantCheckResource) -> None:
        self._variant_check = variant_check

        self.create = async_to_raw_response_wrapper(
            variant_check.create,
        )
        self.retrieve_status = async_to_raw_response_wrapper(
            variant_check.retrieve_status,
        )


class VariantCheckResourceWithStreamingResponse:
    def __init__(self, variant_check: VariantCheckResource) -> None:
        self._variant_check = variant_check

        self.create = to_streamed_response_wrapper(
            variant_check.create,
        )
        self.retrieve_status = to_streamed_response_wrapper(
            variant_check.retrieve_status,
        )


class AsyncVariantCheckResourceWithStreamingResponse:
    def __init__(self, variant_check: AsyncVariantCheckResource) -> None:
        self._variant_check = variant_check

        self.create = async_to_streamed_response_wrapper(
            variant_check.create,
        )
        self.retrieve_status = async_to_streamed_response_wrapper(
            variant_check.retrieve_status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["SessionListProductsResponse", "Data", "DataProduct", "DataProductVariantCheck"]


class DataProductVariantCheck(BaseModel):
    completed_at: Optional[str] = FieldInfo(alias="completedAt", default=None)

    created_at: str = FieldInfo(alias="createdAt")

    error_message: Optional[str] = FieldInfo(alias="errorMessage", default=None)

    request_id: str = FieldInfo(alias="requestId")

    result: object

    status: str


class DataProduct(BaseModel):
    name: str
    """Product name"""

    price: str
    """Product price"""

    product_link: str = FieldInfo(alias="productLink")
    """Product link"""

    quantity: float
    """Quantity"""

    affiliate_product_link: Optional[str] = FieldInfo(alias="affiliateProductLink", default=None)
    """
    Affiliate product link (if provided, will be used instead of productLink for
    order fulfillment)
    """

    metadata: Optional[Dict[str, str]] = None
    """Product metadata"""

    product_id: Optional[str] = FieldInfo(alias="productId", default=None)
    """Product Id"""

    product_image_link: Optional[str] = FieldInfo(alias="productImageLink", default=None)
    """Product image link (thumbnail)"""

    variant_check: Optional[DataProductVariantCheck] = FieldInfo(alias="variantCheck", default=None)


class Data(BaseModel):
    products: List[DataProduct]


class SessionListProductsResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .items import (
    ItemsResource,
    AsyncItemsResource,
    ItemsResourceWithRawResponse,
    AsyncItemsResourceWithRawResponse,
    ItemsResourceWithStreamingResponse,
    AsyncItemsResourceWithStreamingResponse,
)
from ...types import cart_create_checkout_params
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.cart_create_checkout_response import CartCreateCheckoutResponse

__all__ = ["CartResource", "AsyncCartResource"]


class CartResource(SyncAPIResource):
    @cached_property
    def items(self) -> ItemsResource:
        return ItemsResource(self._client)

    @cached_property
    def with_raw_response(self) -> CartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return CartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return CartResourceWithStreamingResponse(self)

    def create_checkout(
        self,
        *,
        x_user_id: str,
        auth: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CartCreateCheckoutResponse:
        """
        Generates a hosted checkout URL for the user's cart that can be embedded in an
        iframe or modal. The page walks the buyer through reviewing the order, entering
        shipping and payment information, and confirming the purchase.

        Args:
          auth: Whether authentication is required for checkout (default: true)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._post(
            "/cart/checkout",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"auth": auth}, cart_create_checkout_params.CartCreateCheckoutParams),
            ),
            cast_to=CartCreateCheckoutResponse,
        )


class AsyncCartResource(AsyncAPIResource):
    @cached_property
    def items(self) -> AsyncItemsResource:
        return AsyncItemsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCartResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncCartResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCartResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncCartResourceWithStreamingResponse(self)

    async def create_checkout(
        self,
        *,
        x_user_id: str,
        auth: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CartCreateCheckoutResponse:
        """
        Generates a hosted checkout URL for the user's cart that can be embedded in an
        iframe or modal. The page walks the buyer through reviewing the order, entering
        shipping and payment information, and confirming the purchase.

        Args:
          auth: Whether authentication is required for checkout (default: true)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._post(
            "/cart/checkout",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"auth": auth}, cart_create_checkout_params.CartCreateCheckoutParams),
            ),
            cast_to=CartCreateCheckoutResponse,
        )


class CartResourceWithRawResponse:
    def __init__(self, cart: CartResource) -> None:
        self._cart = cart

        self.create_checkout = to_raw_response_wrapper(
            cart.create_checkout,
        )

    @cached_property
    def items(self) -> ItemsResourceWithRawResponse:
        return ItemsResourceWithRawResponse(self._cart.items)


class AsyncCartResourceWithRawResponse:
    def __init__(self, cart: AsyncCartResource) -> None:
        self._cart = cart

        self.create_checkout = async_to_raw_response_wrapper(
            cart.create_checkout,
        )

    @cached_property
    def items(self) -> AsyncItemsResourceWithRawResponse:
        return AsyncItemsResourceWithRawResponse(self._cart.items)


class CartResourceWithStreamingResponse:
    def __init__(self, cart: CartResource) -> None:
        self._cart = cart

        self.create_checkout = to_streamed_response_wrapper(
            cart.create_checkout,
        )

    @cached_property
    def items(self) -> ItemsResourceWithStreamingResponse:
        return ItemsResourceWithStreamingResponse(self._cart.items)


class AsyncCartResourceWithStreamingResponse:
    def __init__(self, cart: AsyncCartResource) -> None:
        self._cart = cart

        self.create_checkout = async_to_streamed_response_wrapper(
            cart.create_checkout,
        )

    @cached_property
    def items(self) -> AsyncItemsResourceWithStreamingResponse:
        return AsyncItemsResourceWithStreamingResponse(self._cart.items)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.checkout import session_create_quote_params, session_confirm_checkout_params
from ...types.checkout.session_create_quote_response import SessionCreateQuoteResponse
from ...types.checkout.session_list_products_response import SessionListProductsResponse
from ...types.checkout.session_confirm_checkout_response import SessionConfirmCheckoutResponse
from ...types.checkout.session_retrieve_shipping_info_response import SessionRetrieveShippingInfoResponse

__all__ = ["SessionResource", "AsyncSessionResource"]


class SessionResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SessionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return SessionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SessionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return SessionResourceWithStreamingResponse(self)

    def confirm_checkout(
        self,
        *,
        x_session_token: str,
        shipping_details: session_confirm_checkout_params.ShippingDetails | Omit = omit,
        x_user_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionConfirmCheckoutResponse:
        """
        Confirms the checkout session and creates an order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "x-session-token": x_session_token,
                    "x-user-id": x_user_id,
                }
            ),
            **(extra_headers or {}),
        }
        return self._post(
            "/checkout/session/confirm",
            body=maybe_transform(
                {"shipping_details": shipping_details}, session_confirm_checkout_params.SessionConfirmCheckoutParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionConfirmCheckoutResponse,
        )

    def create_quote(
        self,
        *,
        shipping_details: session_create_quote_params.ShippingDetails,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionCreateQuoteResponse:
        """
        Creates or updates a checkout session with shipping details and returns pricing
        metadata plus a session token.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return self._post(
            "/checkout/session/quote",
            body=maybe_transform(
                {"shipping_details": shipping_details}, session_create_quote_params.SessionCreateQuoteParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionCreateQuoteResponse,
        )

    def list_products(
        self,
        *,
        x_session_token: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionListProductsResponse:
        """
        Returns products for the checkout session

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-session-token": x_session_token, **(extra_headers or {})}
        return self._get(
            "/checkout/session/products",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionListProductsResponse,
        )

    def retrieve_shipping_info(
        self,
        *,
        x_user_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionRetrieveShippingInfoResponse:
        """
        Retrieves the shipping details for the current checkout session.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"x-user-id": x_user_id}), **(extra_headers or {})}
        return self._get(
            "/checkout/session/shipping",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionRetrieveShippingInfoResponse,
        )


class AsyncSessionResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSessionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#accessing-raw-response-data-eg-headers
        """
        return AsyncSessionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSessionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Henry-Social/henry-sdk-py#with_streaming_response
        """
        return AsyncSessionResourceWithStreamingResponse(self)

    async def confirm_checkout(
        self,
        *,
        x_session_token: str,
        shipping_details: session_confirm_checkout_params.ShippingDetails | Omit = omit,
        x_user_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionConfirmCheckoutResponse:
        """
        Confirms the checkout session and creates an order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {
            **strip_not_given(
                {
                    "x-session-token": x_session_token,
                    "x-user-id": x_user_id,
                }
            ),
            **(extra_headers or {}),
        }
        return await self._post(
            "/checkout/session/confirm",
            body=await async_maybe_transform(
                {"shipping_details": shipping_details}, session_confirm_checkout_params.SessionConfirmCheckoutParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionConfirmCheckoutResponse,
        )

    async def create_quote(
        self,
        *,
        shipping_details: session_create_quote_params.ShippingDetails,
        x_user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionCreateQuoteResponse:
        """
        Creates or updates a checkout session with shipping details and returns pricing
        metadata plus a session token.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-user-id": x_user_id, **(extra_headers or {})}
        return await self._post(
            "/checkout/session/quote",
            body=await async_maybe_transform(
                {"shipping_details": shipping_details}, session_create_quote_params.SessionCreateQuoteParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionCreateQuoteResponse,
        )

    async def list_products(
        self,
        *,
        x_session_token: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionListProductsResponse:
        """
        Returns products for the checkout session

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-session-token": x_session_token, **(extra_headers or {})}
        return await self._get(
            "/checkout/session/products",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionListProductsResponse,
        )

    async def retrieve_shipping_info(
        self,
        *,
        x_user_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SessionRetrieveShippingInfoResponse:
        """
        Retrieves the shipping details for the current checkout session.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"x-user-id": x_user_id}), **(extra_headers or {})}
        return await self._get(
            "/checkout/session/shipping",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SessionRetrieveShippingInfoResponse,
        )


class SessionResourceWithRawResponse:
    def __init__(self, session: SessionResource) -> None:
        self._session = session

        self.confirm_checkout = to_raw_response_wrapper(
            session.confirm_checkout,
        )
        self.create_quote = to_raw_response_wrapper(
            session.create_quote,
        )
        self.list_products = to_raw_response_wrapper(
            session.list_products,
        )
        self.retrieve_shipping_info = to_raw_response_wrapper(
            session.retrieve_shipping_info,
        )


class AsyncSessionResourceWithRawResponse:
    def __init__(self, session: AsyncSessionResource) -> None:
        self._session = session

        self.confirm_checkout = async_to_raw_response_wrapper(
            session.confirm_checkout,
        )
        self.create_quote = async_to_raw_response_wrapper(
            session.create_quote,
        )
        self.list_products = async_to_raw_response_wrapper(
            session.list_products,
        )
        self.retrieve_shipping_info = async_to_raw_response_wrapper(
            session.retrieve_shipping_info,
        )


class SessionResourceWithStreamingResponse:
    def __init__(self, session: SessionResource) -> None:
        self._session = session

        self.confirm_checkout = to_streamed_response_wrapper(
            session.confirm_checkout,
        )
        self.create_quote = to_streamed_response_wrapper(
            session.create_quote,
        )
        self.list_products = to_streamed_response_wrapper(
            session.list_products,
        )
        self.retrieve_shipping_info = to_streamed_response_wrapper(
            session.retrieve_shipping_info,
        )


class AsyncSessionResourceWithStreamingResponse:
    def __init__(self, session: AsyncSessionResource) -> None:
        self._session = session

        self.confirm_checkout = async_to_streamed_response_wrapper(
            session.confirm_checkout,
        )
        self.create_quote = async_to_streamed_response_wrapper(
            session.create_quote,
        )
        self.list_products = async_to_streamed_response_wrapper(
            session.list_products,
        )
        self.retrieve_shipping_info = async_to_streamed_response_wrapper(
            session.retrieve_shipping_info,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .cart import (
    CartResource,
    AsyncCartResource,
    CartResourceWithRawResponse,
    AsyncCartResourceWithRawResponse,
    CartResourceWithStreamingResponse,
    AsyncCartResourceWithStreamingResponse,
)
from .items import (
    ItemsResource,
    AsyncItemsResource,
    ItemsResourceWithRawResponse,
    AsyncItemsResourceWithRawResponse,
    ItemsResourceWithStreamingResponse,
    AsyncItemsResourceWithStreamingResponse,
)

__all__ = [
    "ItemsResource",
    "AsyncItemsResource",
    "ItemsResourceWithRawResponse",
    "AsyncItemsResourceWithRawResponse",
    "ItemsResourceWithStreamingResponse",
    "AsyncItemsResourceWithStreamingResponse",
    "CartResource",
    "AsyncCartResource",
    "CartResourceWithRawResponse",
    "AsyncCartResourceWithRawResponse",
    "CartResourceWithStreamingResponse",
    "AsyncCartResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["ItemAddResponse", "Data", "DataAddedProduct", "DataCartSummary", "DataUpdatedProduct", "DataVariantCheck"]


class DataAddedProduct(BaseModel):
    name: str

    price: str

    product_id: str = FieldInfo(alias="productId")

    quantity: float


class DataCartSummary(BaseModel):
    total_items: float

    total_unique_products: float


class DataUpdatedProduct(BaseModel):
    added_quantity: float = FieldInfo(alias="addedQuantity")

    name: str

    previous_quantity: float = FieldInfo(alias="previousQuantity")

    price: str

    product_id: str = FieldInfo(alias="productId")

    quantity: float


class DataVariantCheck(BaseModel):
    product_id: str = FieldInfo(alias="productId")

    status: str

    variant_check_request_id: str = FieldInfo(alias="variantCheckRequestId")


class Data(BaseModel):
    added_products: List[DataAddedProduct]

    cart_summary: DataCartSummary

    updated_products: List[DataUpdatedProduct]

    variant_checks: Optional[List[DataVariantCheck]] = None


class ItemAddResponse(BaseModel):
    message: str

    status: str

    success: bool

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ProductRetrieveDetailsParams"]


class ProductRetrieveDetailsParams(TypedDict, total=False):
    product_id: Required[Annotated[str, PropertyInfo(alias="productId")]]
    """Product ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .products import (
    ProductsResource,
    AsyncProductsResource,
    ProductsResourceWithRawResponse,
    AsyncProductsResourceWithRawResponse,
    ProductsResourceWithStreamingResponse,
    AsyncProductsResourceWithStreamingResponse,
)
from .variant_check import (
    VariantCheckResource,
    AsyncVariantCheckResource,
    VariantCheckResourceWithRawResponse,
    AsyncVariantCheckResourceWithRawResponse,
    VariantCheckResourceWithStreamingResponse,
    AsyncVariantCheckResourceWithStreamingResponse,
)

__all__ = [
    "VariantCheckResource",
    "AsyncVariantCheckResource",
    "VariantCheckResourceWithRawResponse",
    "AsyncVariantCheckResourceWithRawResponse",
    "VariantCheckResourceWithStreamingResponse",
    "AsyncVariantCheckResourceWithStreamingResponse",
    "ProductsResource",
    "AsyncProductsResource",
    "ProductsResourceWithRawResponse",
    "AsyncProductsResourceWithRawResponse",
    "ProductsResourceWithStreamingResponse",
    "AsyncProductsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .product_search_params import ProductSearchParams as ProductSearchParams
from .product_search_response import ProductSearchResponse as ProductSearchResponse
from .cart_create_checkout_params import CartCreateCheckoutParams as CartCreateCheckoutParams
from .merchant_check_status_params import MerchantCheckStatusParams as MerchantCheckStatusParams
from .cart_create_checkout_response import CartCreateCheckoutResponse as CartCreateCheckoutResponse
from .merchant_check_status_response import MerchantCheckStatusResponse as MerchantCheckStatusResponse
from .merchant_list_supported_params import MerchantListSupportedParams as MerchantListSupportedParams
from .order_retrieve_status_response import OrderRetrieveStatusResponse as OrderRetrieveStatusResponse
from .product_retrieve_details_params import ProductRetrieveDetailsParams as ProductRetrieveDetailsParams
from .merchant_list_supported_response import MerchantListSupportedResponse as MerchantListSupportedResponse
from .merchant_get_shipping_info_params import MerchantGetShippingInfoParams as MerchantGetShippingInfoParams
from .product_retrieve_details_response import ProductRetrieveDetailsResponse as ProductRetrieveDetailsResponse
from .merchant_get_shipping_info_response import MerchantGetShippingInfoResponse as MerchantGetShippingInfoResponse
from .wallet_create_card_collection_params import WalletCreateCardCollectionParams as WalletCreateCardCollectionParams
from .wallet_create_card_collection_response import (
    WalletCreateCardCollectionResponse as WalletCreateCardCollectionResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["VariantCheckCreateParams", "Product"]


class VariantCheckCreateParams(TypedDict, total=False):
    product: Required[Product]
    """Product details to check variant availability for"""

    x_user_id: Annotated[str, PropertyInfo(alias="x-user-id")]


class Product(TypedDict, total=False):
    affiliate_product_link: Annotated[str, PropertyInfo(alias="affiliateProductLink")]
    """
    Affiliate product link (if provided, will be used instead of productLink for
    order fulfillment)
    """

    metadata: Dict[str, str]
    """Product metadata"""

    name: str
    """Product name"""

    price: str
    """Product price"""

    product_id: Annotated[str, PropertyInfo(alias="productId")]
    """Product Id"""

    product_image_link: Annotated[str, PropertyInfo(alias="productImageLink")]
    """Product image link (thumbnail)"""

    product_link: Annotated[str, PropertyInfo(alias="productLink")]
    """Product link"""

    quantity: float
    """Quantity"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .item_add_params import ItemAddParams as ItemAddParams
from .item_add_response import ItemAddResponse as ItemAddResponse
from .item_list_response import ItemListResponse as ItemListResponse
from .item_clear_response import ItemClearResponse as ItemClearResponse
from .item_remove_response import ItemRemoveResponse as ItemRemoveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["MerchantGetShippingInfoParams"]


class MerchantGetShippingInfoParams(TypedDict, total=False):
    domain: str
    """Merchant domain to filter by"""

    limit: int
    """Number of items per page (1-100)"""

    merchant_id: Annotated[str, PropertyInfo(alias="merchantId")]
    """Merchant ID to filter by"""

    offset: int
    """Number of items to skip"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["SessionConfirmCheckoutParams", "ShippingDetails"]


class SessionConfirmCheckoutParams(TypedDict, total=False):
    x_session_token: Required[Annotated[str, PropertyInfo(alias="x-session-token")]]

    shipping_details: Annotated[ShippingDetails, PropertyInfo(alias="shippingDetails")]

    x_user_id: Annotated[str, PropertyInfo(alias="x-user-id")]


class ShippingDetails(TypedDict, total=False):
    address_line1: Required[Annotated[str, PropertyInfo(alias="addressLine1")]]
    """Address line 1"""

    city: Required[str]
    """City"""

    country_code: Required[Annotated[str, PropertyInfo(alias="countryCode")]]
    """Country code"""

    email: Required[str]
    """Email"""

    full_name: Required[Annotated[str, PropertyInfo(alias="fullName")]]
    """Full name"""

    phone_number: Required[Annotated[str, PropertyInfo(alias="phoneNumber")]]
    """Phone number"""

    postal_code: Required[Annotated[str, PropertyInfo(alias="postalCode")]]
    """Postal code"""

    state_or_province: Required[Annotated[str, PropertyInfo(alias="stateOrProvince")]]
    """State or province"""

    address_line2: Annotated[Optional[str], PropertyInfo(alias="addressLine2")]
    """Address line 2"""
